@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef LINEEDITCATCHRETURNKEY_H
-#define LINEEDITCATCHRETURNKEY_H
+#pragma once
 
 #include "kdepim_export.h"
 #include <QObject>
@@ -27,7 +26,6 @@ protected:
     bool eventFilter(QObject *obj, QEvent *event) override;
 
 private:
-    QLineEdit *mLineEdit = nullptr;
+    QLineEdit *const mLineEdit;
 };
 }
-#endif // LINEEDITCATCHRETURNKEY_H
