@@ -76,7 +76,7 @@ protected:
     void resizeEvent(QResizeEvent *event) override;
 
 private:
-    QWidget *mBigBox = nullptr;
+    QWidget *const mBigBox = nullptr;
 };
 
 class TransactionItem : public QWidget
@@ -167,4 +167,3 @@ protected:
     bool mWasLastShown = false;
 };
 } // namespace KPIM
-
