@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -12,9 +12,7 @@ using namespace KPIM;
 class KPIM::ProgressStatusBarWidgetPrivate
 {
 public:
-    ProgressStatusBarWidgetPrivate()
-    {
-    }
+    ProgressStatusBarWidgetPrivate() = default;
 
     KPIM::StatusbarProgressWidget *mLittleProgress = nullptr;
 };
@@ -34,10 +32,7 @@ ProgressStatusBarWidget::ProgressStatusBarWidget(QWidget *alignWidget, QWidget *
     d->mLittleProgress->show();
 }
 
-ProgressStatusBarWidget::~ProgressStatusBarWidget()
-{
-    delete d;
-}
+ProgressStatusBarWidget::~ProgressStatusBarWidget() = default;
 
 KPIM::StatusbarProgressWidget *ProgressStatusBarWidget::littleProgress() const
 {
